@@ -1,6 +1,6 @@
 import traceback
 import numpy as np
-import httpx
+import wget
 from aiohttp_retry import ExponentialRetry, RetryClient
 
 from hamunafs.utils.minio import MinioAgent
@@ -58,13 +58,8 @@ class MinioBackend(BackendBase):
                 return False, '下载出错'
             else:
                 url = 'http://{}/{}/{}'.format(self.domain, self.default_bucket, '{}_{}'.format(bucket, bucket_name))
-                with httpx.stream('GET', url) as response:
-                    if response.status_code == 200:
-                        with open(download_path, mode='wb') as f:
-                            for chunk in response.iter_bytes():
-                                f.write(chunk)
-                    else:
-                        raise ValueError()
+                print('downloading {} -> {}'.format(url, download_path))
+                download_path = wget.download(url, download_path)
                 return True, download_path
         except Exception as e:
             if tries >= 3:
