@@ -3,6 +3,7 @@ import traceback
 import httpx
 from aiohttp_retry import ExponentialRetry, RetryClient
 from aiofile import async_open
+import wget
 
 from qiniu import put_file, put_data, Auth, etag
 from qiniu import BucketManager, build_batch_delete
@@ -68,14 +69,8 @@ class Qiniu(BackendBase):
                 return False, '下载出错'
             else:
                 url = 'http://{}/{}'.format(self.domain, '{}_{}'.format(bucket, bucket_name))
-                print(url)
-                with httpx.stream('GET', url) as response:
-                    if response.status_code == 200:
-                        with open(download_path, mode='wb') as f:
-                            for chunk in response.iter_bytes():
-                                f.write(chunk)
-                    else:
-                        raise ValueError()
+                print('downloading {} -> {}'.format(url, download_path))
+                download_path = wget.download(url, download_path)
                 return True, download_path
         except Exception as e:
             if tries >= 3:
@@ -84,24 +79,7 @@ class Qiniu(BackendBase):
                 return self.get(download_path, bucket, bucket_name, tries+1)
 
     async def get_async(self, download_path, bucket, bucket_name):
-        try:
-            url = 'http://{}/{}'.format(self.domain, '{}_{}'.format(bucket, bucket_name))
-            print(url)
-            retry_opts = ExponentialRetry(attempts=3)
-            async with RetryClient(retry_options=retry_opts) as session:
-                async with session.get(url) as response:
-                    if response.status == 200:
-                        async with async_open(download_path, mode='wb') as f:
-                            while True:
-                                chunk = await response.content.read(4096)
-                                if not chunk:
-                                    break
-                                await f.write(chunk)
-                    else:
-                        raise ValueError()
-            return True, download_path
-        except Exception as e:
-            return False, str(e)
+        return self.get(download_path, bucket, bucket_name)
 
 
             
