@@ -9,6 +9,7 @@ import asyncio
 import time
 import os
 import argparse
+import shutil
 
 from hamunafs.utils.nsqmanager import MQManager
 from hamunafs.sqlite import DB
@@ -77,7 +78,7 @@ async def file_transfer_put(url, bucket, bucket_name, ttl):
     if await cache_engine.get_cache_async(key, return_obj=False) is not None:
         return
     
-    with cache_engine.lock(key, ttl=10) as lock:
+    with cache_engine.lock(key, ttl=30) as lock:
         if lock:
             try:
                 if await cache_engine.get_cache_async(key, return_obj=False) is not None:
@@ -213,6 +214,8 @@ async def extra_tasks():
                     continue
                 await hmfs_client.cleanup_cloud()
                 cache_engine.cache('hmfs_cleanup', 1, expired=7200)
+
+                shutil.rmtree(cache_path, ignore_errors=True)
         except:
             traceback.print_exc()
         finally:
