@@ -18,6 +18,7 @@ class XRedis(Singleton):
         self.db = db
         self.locker = threading.Lock()
         self.connection_lost = True
+        self.stopped = False
         
         self._make_conn()
         self._inited = True
@@ -35,12 +36,13 @@ class XRedis(Singleton):
         # self._ping()
         
     def _ping(self):
-        while not self.connection_lost:
+        while not self.connection_lost or not self.stopped:
             if self.set('ping', 'ok', expired=30):
                 print('pinged')
             else:
                 self.connection_lost = True
                 print('连接丢失')
+                break
                 
             time.sleep(30)
             
@@ -49,12 +51,13 @@ class XRedis(Singleton):
             print('释放连接')
             self.conn.close()
             self.connection_lost = True
-            if self.heartbeat_thread.isAlive:
-                self.heartbeat_thread.join()
+            
             del self.conn
     
     def _make_conn(self):
         try:
+            if self.stopped:
+                return
             self.__release_conn()
             print('创建新连接')
             pool = redis.ConnectionPool(
@@ -272,6 +275,9 @@ class XRedis(Singleton):
     def close(self):
         try:
             self.__release_conn()
+            self.stopped = True
+            if self.heartbeat_thread.isAlive:
+                self.heartbeat_thread.join()
         except Exception as e:
             traceback.print_exc()
         
